==> reportico-4.6.zip: reportico-4.6/projects/admin/lang_ar_ar.php <==
<?php namespace reportico\reportico\components;

$g_translations = array (
        "ar_ar" => array (
            "Project Name" => "اسم المشروع",
            "Project Title" => "عنوان المشروع",
            "Database Type" => "نوع قاعدة البيانات",
            "Host Name" => "اسم المضيف",
            "Database Name" => "اسم قاعدة البيانات",
            "User Name" => "اسم المستخدم",
            "Password" => "كلمة السر",
            "Base URL" => "URL قاعدة",
            "Server (Informix Only)" => "خادم (ينفورميكس فقط)",
            "Protocol (Informix Only)" => "بروتوكول (ينفورميكس فقط)",
            "Database<br>Character Encoding" => "قاعدة البيانات الشخصية <BR> ترميز",
            "Output<br>Character Encoding" => "إخراج ترميز الأحرف",
            "Project Language" => "لغة مشروع",
            "Stylesheet" => "الأنماط",
            "Project Password" => "مشروع كلمة",
            "Display Date Format" => "العرض تنسيق التاريخ",
            "Database Date (for MySql leave as default YYYY-MM-DD)" => "تاريخ قاعدة البيانات (لمسقل ترك كما الافتراضي YYYY-MM-DD)",



            "HELP_PROJECT_NAME" => "اسم المشروع. سيتم إنشاء مجلد بهذا الاسم تحت المجلد 'المشاريع' ضمن مدير تركيب Reportico",
            "HELP_PROJECT_TITLE" => "وهو اللقب الذي سيظهر في أعلى القائمة جناح تقرير .. أي اسم الانسان ومفهومة للمشروع",
            "HELP_DATABASE_TYPE" => "نوع قاعدة البيانات التي تريد أن تقدم تقريرا ضده.",
            "HELP_DATABASE_HOST" => "عنوان IP أو اسم المضيف حيث تقع قاعدة البيانات للحصول على قاعدة بيانات على نفس الجهاز مثل 127.0.0.1 استخدام الشبكة العالمية للحصول على بيانات SQLite ترك كافتراض. لأوراكل، ماي وقواعد البيانات كيو الاستماع على منفذ غير قياسي، يمكنك تحديد في شكل HOSTNAME: PORT أو IPADDRESS: PORT ",
            "HELP_DATABASE_NAME" => "اسم قاعدة البيانات إلى تقارير ضد للحصول على بيانات SQLite تدخل المسار الكامل لملف قاعدة البيانات.",
            "HELP_DATABASE_USER" => "اسم المستخدم المطلوبة للاتصال قاعدة البيانات",
            "HELP_DATABASE_PASSWORD" => "كلمة المرور المطلوبة للاتصال قاعدة البيانات",
            "HELP_DB_ENCODING" => "تنسيق الترميز المستخدم لتخزين الأحرف في قاعدة البيانات الخاصة بك. قبول الافتراضي بلا ستعمل بشكل طبيعي وإلا سوف UTF8 العمل للمناطق الناطقة باللغة الإنجليزية ومعظم الحالات الأخرى. يمكنك دائما أعود إلى صفحة التكوين لتغييره في وقت لاحق ",
            "HELP_OUTPUT_ENCODING" => "الافتراضي هو UTF8 الذي هو عادة أفضل. عند إخراج البيانات، سيتم تحويل الانتاج الى هذا الشكل قبل إصدار المتصفح، PDF المشاهد الخ",
            "HELP_PASSWORD" => "اختيار كلمة مرور التي يجب أن يجب على المستخدمين الدخول للوصول إلى تقارير المشاريع. ترك هذا فارغا للسماح بالوصول إلى مشروع بدون كلمة مرور.",
            "HELP_LANGUAGE" => "اختيار اللغة الافتراضية يجب تشغيل هذا الجناح التقرير. افتراضيا اللغة الإنجليزية هي الخيار الوحيد. هناك عدد قليل من حزم اللغات الأخرى المتاحة التي سوف تجد تحت اللغة / حزم مجلد في مكان ما تحت المجلد المساعد Reportico. نقل أي تلك التي تحتاج إلى مجلد اللغة ",
            "HELP_DB_DATE" => "اختر تنسيق التاريخ الذي يتم تخزين التمور في قاعدة البيانات الخاصة بك. لماي ومعظم قواعد البيانات الأخرى، ووضع YYYY-MM-DD هو الصحيح",
            "HELP_DATE_FORMAT" => "اختيار شكل التاريخ الذي ترغب في استخدامه لعرض وإدخال التواريخ",
            "HELP_SAFE_MODE" => "عند تشغيلها، ووضع التصميم منع دخول رمز المستخدم المخصصة، وتحديد المهام، والبيانات SQL (تجنب دخول غير المرغوب فيها من أوامر PHP الخطيرة وحقن SQL)
إيقاف هذا لتمكين الوصول إلى هذه الوظائف. ",
            )
            );


$g_report_desc = array(
    "ar_ar" => array(
        "createproject" =>
        "
إنشاء مجلد المشاريع الجديدة التي يمكنك إنشاء مجموعة من التقارير.
<BR>
يجب توفير على الأقل اسم المشروع الذي هو اسم المجلد تستخدم لإنشاء التقارير، وعنوان المشروع لجناح التقرير الخاص بك.
<P>
إذا كنت توفير جناح تقرير للمستخدمين على موقع على شبكة الإنترنت التي قد ترغب في حماية كلمة السر الوصول إلى تقارير طريق وضع كلمة مرور التقرير. ترك ذلك فارغا.
<P>
عندما كنت سعيدا اضغط على زر العودة.
<P>
"),
        );

$g_report_desc ["ar_ar"] ["configureproject"] =
"
تغيير عناصر التكوين لهذا المشروع.
<BR>
يمكنك تغيير العنوان، واللغة الافتراضية، تعيين كلمة مرور المشروع، وترميز الأحرف وتنسيق التاريخ.
<P>
عندما كنت سعيدا اضغط على زر العودة.
<P>
";
?>

==> reportico-7.1.zip: reportico-7.1/projects/admin/lang_ar_ar.php <==
<?php namespace Reportico\Engine;

$translations = array (
        "ar_ar" => array (
            "Project Name" => "اسم المشروع",
            "Project Title" => "عنوان المشروع",
            "Database Type" => "نوع قاعدة البيانات",
            "Host Name" => "اسم المضيف",
            "Database Name" => "اسم قاعدة البيانات",
            "User Name" => "اسم المستخدم",
            "Password" => "كلمة السر",
            "Base URL" => "URL قاعدة",
            "Server (Informix Only)" => "خادم (ينفورميكس فقط)",
            "Protocol (Informix Only)" => "بروتوكول (ينفورميكس فقط)",
            "Database<br>Character Encoding" => "قاعدة البيانات الشخصية <BR> ترميز",
            "Output<br>Character Encoding" => "إخراج ترميز الأحرف",
            "Project Language" => "لغة مشروع",
            "Stylesheet" => "الأنماط",
            "Project Password" => "مشروع كلمة",
            "Display Date Format" => "العرض تنسيق التاريخ",
            "Database Date (for MySql leave as default YYYY-MM-DD)" => "تاريخ قاعدة البيانات (لمسقل ترك كما الافتراضي YYYY-MM-DD)",



            "HELP_PROJECT_NAME" => "اسم المشروع. سيتم إنشاء مجلد بهذا الاسم تحت المجلد 'المشاريع' ضمن مدير تركيب Reportico",
            "HELP_PROJECT_TITLE" => "وهو اللقب الذي سيظهر في أعلى القائمة جناح تقرير .. أي اسم الانسان ومفهومة للمشروع",
            "HELP_DATABASE_TYPE" => "نوع قاعدة البيانات التي تريد أن تقدم تقريرا ضده.",
            "HELP_DATABASE_HOST" => "عنوان IP أو اسم المضيف حيث تقع قاعدة البيانات للحصول على قاعدة بيانات على نفس الجهاز مثل 127.0.0.1 استخدام الشبكة العالمية للحصول على بيانات SQLite ترك كافتراض. لأوراكل، ماي وقواعد البيانات كيو الاستماع على منفذ غير قياسي، يمكنك تحديد في شكل HOSTNAME: PORT أو IPADDRESS: PORT ",
            "HELP_DATABASE_NAME" => "اسم قاعدة البيانات إلى تقارير ضد للحصول على بيانات SQLite تدخل المسار الكامل لملف قاعدة البيانات.",
            "HELP_DATABASE_USER" => "اسم المستخدم المطلوبة للاتصال قاعدة البيانات",
            "HELP_DATABASE_PASSWORD" => "كلمة المرور المطلوبة للاتصال قاعدة البيانات",
            "HELP_DB_ENCODING" => "تنسيق الترميز المستخدم لتخزين الأحرف في قاعدة البيانات الخاصة بك. قبول الافتراضي بلا ستعمل بشكل طبيعي وإلا سوف UTF8 العمل للمناطق الناطقة باللغة الإنجليزية ومعظم الحالات الأخرى. يمكنك دائما أعود إلى صفحة التكوين لتغييره في وقت لاحق ",
            "HELP_OUTPUT_ENCODING" => "الافتراضي هو UTF8 الذي هو عادة أفضل. عند إخراج البيانات، سيتم تحويل الانتاج الى هذا الشكل قبل إصدار المتصفح، PDF المشاهد الخ",
            "HELP_PASSWORD" => "اختيار كلمة مرور التي يجب أن يجب على المستخدمين الدخول للوصول إلى تقارير المشاريع. ترك هذا فارغا للسماح بالوصول إلى مشروع بدون كلمة مرور.",
            "HELP_LANGUAGE" => "اختيار اللغة الافتراضية يجب تشغيل هذا الجناح التقرير. افتراضيا اللغة الإنجليزية هي الخيار الوحيد. هناك عدد قليل من حزم اللغات الأخرى المتاحة التي سوف تجد تحت اللغة / حزم مجلد في مكان ما تحت المجلد المساعد Reportico. نقل أي تلك التي تحتاج إلى مجلد اللغة ",
            "HELP_DB_DATE" => "اختر تنسيق التاريخ الذي يتم تخزين التمور في قاعدة البيانات الخاصة بك. لماي ومعظم قواعد البيانات الأخرى، ووضع YYYY-MM-DD هو الصحيح",
            "HELP_DATE_FORMAT" => "اختيار شكل التاريخ الذي ترغب في استخدامه لعرض وإدخال التواريخ",
            "HELP_SAFE_MODE" => "عند تشغيلها، ووضع التصميم منع دخول رمز المستخدم المخصصة، وتحديد المهام، والبيانات SQL (تجنب دخول غير المرغوب فيها من أوامر PHP الخطيرة وحقن SQL)
إيقاف هذا لتمكين الوصول إلى هذه الوظائف. ",
            )
            );


$report_desc = array(
    "ar_ar" => array(
        "createproject" =>
        "
إنشاء مجلد المشاريع الجديدة التي يمكنك إنشاء مجموعة من التقارير.
<BR>
يجب توفير على الأقل اسم المشروع الذي هو اسم المجلد تستخدم لإنشاء التقارير، وعنوان المشروع لجناح التقرير الخاص بك.
<P>
إذا كنت توفير جناح تقرير للمستخدمين على موقع على شبكة الإنترنت التي قد ترغب في حماية كلمة السر الوصول إلى تقارير طريق وضع كلمة مرور التقرير. ترك ذلك فارغا.
<P>
عندما كنت سعيدا اضغط على زر العودة.
<P>
"),
        );

$report_desc ["ar_ar"] ["configureproject"] =
"
تغيير عناصر التكوين لهذا المشروع.
<BR>
يمكنك تغيير العنوان، واللغة الافتراضية، تعيين كلمة مرور المشروع، وترميز الأحرف وتنسيق التاريخ.
<P>
عندما كنت سعيدا اضغط على زر العودة.
<P>
";

ReporticoApp::set("translations", $translations);
ReporticoApp::set("report_desc", $report_desc);

?>
